"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createIORedisClient = void 0;
const ioredis_1 = __importDefault(require("ioredis"));
const shared_1 = require("@cubejs-backend/shared");
const fs_1 = __importDefault(require("fs"));
const utils_1 = require("./utils");
// @ts-ignore
ioredis_1.default.Pipeline.prototype.execAsync = function execAsync() {
    return this.exec()
        .then((array) => (array ? array.map((skipFirst) => skipFirst[1]) : array));
};
function decorateRedisClient(client) {
    [
        'brpop',
        'del',
        'get',
        'hget',
        'rpop',
        'set',
        'zadd',
        'zrange',
        'zrangebyscore',
        'keys',
        'watch',
        'unwatch',
        'incr',
        'decr',
        'lpush',
    ].forEach(k => {
        client[`${k}Async`] = client[k];
    });
    client.end = () => client.disconnect();
    return client;
}
async function createIORedisClient(url, opts) {
    const options = {
        enableReadyCheck: true,
        lazyConnect: true
    };
    const parsedUrl = utils_1.parseRedisUrl(url);
    if (parsedUrl.sentinels) {
        options.sentinels = parsedUrl.sentinels;
        options.name = parsedUrl.name;
        options.db = parsedUrl.db;
        options.enableOfflineQueue = false;
    }
    else {
        options.username = parsedUrl.username;
        options.password = parsedUrl.password;
        options.host = parsedUrl.host;
        options.port = parsedUrl.port;
        options.path = parsedUrl.path;
        options.db = parsedUrl.db;
        if (parsedUrl.ssl) {
            options.tls = {};
        }
    }
    if (shared_1.getEnv('redisTls')) {
        // codefresh code added for supporting mtls
        if (shared_1.getEnv('redisCaPath') && shared_1.getEnv('redisCertPath') && shared_1.getEnv('redisKeyPath')) {
            options.tls = {
                ca: fs_1.default.readFileSync(shared_1.getEnv('redisCaPath')),
                cert: fs_1.default.readFileSync(shared_1.getEnv('redisCertPath')),
                key: fs_1.default.readFileSync(shared_1.getEnv('redisKeyPath')),
                rejectUnauthorized: shared_1.getEnv('redisRejectUnauthorized')
            };
        }
        else {
            options.tls = {};
        }
    }
    const password = shared_1.getEnv('redisPassword');
    if (password) {
        options.password = password;
    }
    const client = new ioredis_1.default({
        ...options,
        ...opts,
    });
    await client.connect();
    return decorateRedisClient(client);
}
exports.createIORedisClient = createIORedisClient;
//# sourceMappingURL=IORedisFactory.js.map