import { QueryCache } from './QueryCache';
import { PreAggregations, PreAggregationDescription } from './PreAggregations';
import { RedisPool, RedisPoolOptions } from './RedisPool';
import { DriverFactory, DriverFactoryByDataSource } from './DriverFactory';
export declare type CacheAndQueryDriverType = 'redis' | 'memory';
export declare enum DriverType {
    External = "external",
    Internal = "internal",
    Cache = "cache"
}
export interface QueryOrchestratorOptions {
    externalDriverFactory?: DriverFactory;
    cacheAndQueueDriver?: CacheAndQueryDriverType;
    redisPoolOptions?: RedisPoolOptions;
    queryCacheOptions?: any;
    preAggregationsOptions?: any;
    rollupOnlyMode?: boolean;
    continueWaitTimeout?: number;
    skipExternalCacheAndQueue?: boolean;
}
export declare class QueryOrchestrator {
    protected readonly redisPrefix: string;
    protected readonly driverFactory: DriverFactoryByDataSource;
    protected readonly logger: any;
    protected readonly queryCache: QueryCache;
    protected readonly preAggregations: PreAggregations;
    protected readonly redisPool: RedisPool | undefined;
    protected readonly rollupOnlyMode: boolean;
    private queueEventsBus;
    private readonly cacheAndQueueDriver;
    constructor(redisPrefix: string, driverFactory: DriverFactoryByDataSource, logger: any, options?: QueryOrchestratorOptions);
    private getQueueEventsBus;
    /**
     * Returns QueryCache instance.
     */
    getQueryCache(): QueryCache;
    /**
     * Returns PreAggregations instance.
     */
    getPreAggregations(): PreAggregations;
    /**
     * Force reconcile queue logic to be executed.
     */
    forceReconcile(datasource?: string): Promise<void>;
    fetchQuery(queryBody: any): Promise<any>;
    loadRefreshKeys(query: any): Promise<any[]>;
    queryStage(queryBody: any): Promise<{
        stage: string;
        timeElapsed: number;
    } | {
        stage: string;
        timeElapsed?: undefined;
    }>;
    resultFromCacheIfExists(queryBody: any): Promise<{
        data: any;
        lastRefreshTime: Date;
    }>;
    testConnections(): Promise<void>;
    cleanup(): Promise<void>;
    getPreAggregationVersionEntries(preAggregations: {
        preAggregation: any;
        partitions: any[];
    }[], preAggregationsSchema: string, requestId: string): Promise<{
        structureVersionsByTableName: any;
        versionEntriesByTableName: any;
    }>;
    getPreAggregationPreview(requestId: string, preAggregation: PreAggregationDescription): Promise<any>;
    expandPartitionsInPreAggregations(queryBody: any): Promise<import("./QueryCache").Query>;
    checkPartitionsBuildRangeCache(queryBody: any): Promise<[unknown, unknown, unknown, unknown, unknown, unknown, unknown, unknown, unknown, unknown]>;
    getPreAggregationQueueStates(dataSource?: string): Promise<any[]>;
    cancelPreAggregationQueriesFromQueue(queryKeys: string[], dataSource?: string): Promise<boolean[]>;
    subscribeQueueEvents(id: any, callback: any): Promise<void>;
    unSubscribeQueueEvents(id: any): Promise<void>;
}
//# sourceMappingURL=QueryOrchestrator.d.ts.map