"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createRedisClient = void 0;
const redis_1 = __importDefault(require("redis"));
const shared_1 = require("@cubejs-backend/shared");
const util_1 = require("util");
const fs_1 = __importDefault(require("fs"));
function decorateRedisClient(client) {
    [
        'brpop',
        'del',
        'get',
        'hget',
        'rpop',
        'set',
        'zadd',
        'zrange',
        'zrangebyscore',
        'keys',
        'watch',
        'unwatch',
        'incr',
        'decr',
        'lpush',
    ].forEach(k => {
        client[`${k}Async`] = util_1.promisify(client[k]);
    });
    return client;
}
redis_1.default.Multi.prototype.execAsync = function execAsync() {
    return new Promise((resolve, reject) => this.exec((err, res) => (err ? reject(err) : resolve(res))));
};
async function createRedisClient(url, opts = {}) {
    const options = {
        url,
    };
    if (shared_1.getEnv('redisTls')) {
        // codefresh code added for supporting mtls
        if (shared_1.getEnv('redisCaPath') && shared_1.getEnv('redisCertPath') && shared_1.getEnv('redisKeyPath')) {
            options.tls = {
                ca: fs_1.default.readFileSync(shared_1.getEnv('redisCaPath')),
                cert: fs_1.default.readFileSync(shared_1.getEnv('redisCertPath')),
                key: fs_1.default.readFileSync(shared_1.getEnv('redisKeyPath')),
                rejectUnauthorized: shared_1.getEnv('redisRejectUnauthorized')
            };
        }
        else {
            options.tls = {};
        }
    }
    if (shared_1.getEnv('redisPassword')) {
        options.password = shared_1.getEnv('redisPassword');
    }
    return decorateRedisClient(redis_1.default.createClient({
        ...options,
        ...opts,
    }));
}
exports.createRedisClient = createRedisClient;
//# sourceMappingURL=RedisFactory.js.map